@@ -22,8 +22,8 @@
 #' @param surv Logical. If FALSE report event probabilities instead of
 #' survival probabilities. Only available for
 #' \code{object$model=="survival"}.
-#' @param cause The cause for predicting the cause-specific cumulative
-#' incidence function in competing risk models.
+#' @param cause For competing risk models. The event of interest for which predictions of the absolute risks are obtained by evaluating the cause-specific cumulative
+#' incidence functions at  \code{times}.
 #' @param intervals Logical. If TRUE count events and censored in
 #' intervals between the values of \code{times}.
 #' @param percent Logical. If TRUE all estimated values are multiplied
@@ -72,7 +72,7 @@
 ##' sx <- summary(fit0,times=c(1,5,10,12),percent=TRUE,intervals=TRUE)
 ##' print(sx,digits=3)
 ##' 
-##' ## show cumulative incidences (1-survival)
+##' ## show absolute risks, i.e., cumulative incidences (1-survival)
 ##' summary(fit0,times=c(1,5,10,12),surv=FALSE,percent=TRUE,intervals=TRUE)
 ##' 
 ##' # Stratified Kaplan-Meier
@@ -107,7 +107,7 @@
 ##' print(summary(fit4,
 ##'               times=c(1,5,10),
 ##'               newdata=data.frame(age=c(20,50,70),sex=c("female","male","male")),
-##'               intervals=TRUE,collapse=TRUE,
+##'               intervals=TRUE,
 ##'               percent=TRUE),digits=3)
 ##' 
 ##' ## assess results from summary
@@ -236,7 +236,7 @@ summary.prodlim <- function(object,
                 ltab <- ltab[Found]
             }
             else stop(paste("\nCannot find cause: ",cause,".\nFitted were causes: ",paste(names(ltab),collapse=", "),sep=""))
-        }else{
+        }else{ ## survival model
             ltab <- lifeTab(object=object,
                             times=times,
                             newdata=X,
